# Sample python file for emdwind-index service through the EMD-API

import emdapiwindindex as windindex
import numpy as np
import pandas as pd


if __name__ == "__main__":
    testUserGuid = '25740f86-b4d6-4472-bbe5-b4e040ca41fb'

    configuration = windindex.Configuration()
    configuration.host = "http://developmentapi.emd.dk/wind-index/"
    configuration.api_key['X-Auth'] = testUserGuid
    windIndexApi = windindex.WindIndexApi(windindex.ApiClient(configuration))

    ''' Get list of turbines to which the test user have access '''
    turbineList = windIndexApi.windindex_controller_get_windindexcalibrated()

    ''' Print list of turbines '''
    print('Turbine List:')
    for turbine in turbineList:
        print(' -', turbine['turbine_id'])

    turbineId = turbineList[0]['turbine_id']
    ''' Get details for the first turbine in the list '''
    turbineDetails = windIndexApi.windindex_controller_get_windindexcalibrateddetails(turbine_id=turbineId)

    ''' Print name of the selected turbine '''
    print('Turbine name:', turbineDetails['name'])

    ''' Get list of wind indexes for the turbine '''
    csvData = windIndexApi.windindex_controller_get_windindexcalibratedwindindices(turbine_id=turbineId)
    ''' Read wind index list into Pandas data frame '''
    from io import StringIO
    csvDataFile = StringIO(csvData)
    windIndexDF = pd.read_csv(csvDataFile)

    ''' List Month Abnormality Index for 2018 '''
    windIndexDF2018 = windIndexDF[windIndexDF['year'] == 2018][['month', 'month_abnormality_index']]
    windIndexDF2018['month'] = windIndexDF2018['month'].astype(np.int8)
    for index, row in windIndexDF2018.iterrows():
        print(f' - {int(row["month"])}: {100*row["month_abnormality_index"]:.2f}%')

    ''' Get wind index for June 2018 '''
    windIndexJune2018 = windIndexApi.windindex_controller_get_windindexcalibratedwindindicesmonth(turbine_id=turbineId, year=2018, month=6)
    print(windIndexJune2018)

    ''' Check that value match value from csv data '''
    print('Wind Index from single month:', windIndexJune2018['month_abnormality_index'])
    print('Wind Index from csv:', windIndexDF2018[windIndexDF2018['month'] == 6]['month_abnormality_index'].values[0])
    import math
    assert(math.isclose(windIndexJune2018['month_abnormality_index'], windIndexDF2018[windIndexDF2018['month'] == 6]['month_abnormality_index'].values[0], abs_tol=1e-6))

    ''' Not sure this will be released to customers '''
    hourData = windIndexApi.windindex_controller_get_windindexcalibratedmodeldata(turbine_id=turbineId, start_date='2018-01-01', end_date='2019-01-01')
    ''' Load into pandas '''
    hourDataFile = StringIO(hourData)
    hourDataDF = pd.read_csv(hourDataFile)
    ''' Print average wind speed modification '''
    print('Average speed up:', hourDataDF['predicted_wind_speed'].mean() - hourDataDF['model_wind_speed'].mean(), 'm/s')

